variable "customer_name" {
  description = "Account canonical name"
}

variable "environment" {
  description = "Account environment type"
  default     = "ops"
}

data "template_file" "s3_policy" {
  template = "${file("${path.module}/s3_policy.json.tpl")}"
  vars {
    customer_name = "${var.customer_name}"
    environment   = "${var.environment}"
  }
}

resource "aws_s3_bucket" "main" {
  bucket        = "${var.customer_name}-${var.environment}-cloudtrail"
  force_destroy = true
  policy        = "${data.template_file.s3_policy.rendered}"
}

resource "aws_cloudtrail" "main" {
  name                          = "${var.customer_name}-${var.environment}-cloudtrail"
  s3_bucket_name                = "${aws_s3_bucket.main.id}"
  include_global_service_events = true
}

output "bucket_name" {
  value = "${aws_s3_bucket.main.id}"
}

output "cloudtrail_name" {
  value = "${aws_cloudtrail.main.id}"
}
